@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use Carp;
 
-our $VERSION = 'v0.4.2'; # VERSION
+our $VERSION = '0.004003'; # VERSION
 
 use Moose;
 with qw(
@@ -110,7 +110,7 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization Reques
 
 =head1 VERSION
 
-version v0.4.2
+version 0.004003
 
 =head1 SYNOPSIS
 
@@ -210,6 +210,12 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
+=head2 comments
+
+Reader: comments
+
+Type: Str
+
 =head2 state
 
 Reader: state
@@ -282,14 +288,6 @@ Reader: phone_number
 
 Type: MooseX::Types::Varchar::Varchar[20]
 
-=head2 total
-
-Reader: total
-
-Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
-
-Additional documentation: Grand total for the order. You must include either this field or item_#_unitPrice in your request
-
 =head2 cc_exp_month
 
 Reader: cc_exp_month
@@ -300,6 +298,14 @@ This attribute is required.
 
 Additional documentation: Two-digit month that the credit card expires in. Format: MM.
 
+=head2 total
+
+Reader: total
+
+Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
+
+Additional documentation: Grand total for the order. You must include either this field or item_#_unitPrice in your request
+
 =head2 username
 
 Reader: username
