@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 'v0.4.2'; # VERSION
+our $VERSION = '0.004003'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -77,7 +77,7 @@ Business::CyberSource::Request::Credit - CyberSource Credit Request Object
 
 =head1 VERSION
 
-version v0.4.2
+version 0.004003
 
 =head1 SYNOPSIS
 
@@ -141,6 +141,12 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
+=head2 comments
+
+Reader: comments
+
+Type: Str
+
 =head2 trace
 
 Reader: trace
