@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use Carp;
 
-our $VERSION = 'v0.4.2'; # VERSION
+our $VERSION = '0.004003'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Credit';
@@ -28,7 +28,7 @@ Business::CyberSource::Request::FollowOnCredit - CyberSource Credit Request Obje
 
 =head1 VERSION
 
-version v0.4.2
+version 0.004003
 
 =head1 SYNOPSIS
 
@@ -75,6 +75,12 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
+=head2 comments
+
+Reader: comments
+
+Type: Str
+
 =head2 trace
 
 Reader: trace
