@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.4.2'; # VERSION
+our $VERSION = '0.004003'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Credit';
@@ -28,7 +28,7 @@ Business::CyberSource::Request::StandAloneCredit - CyberSource Credit Request Ob
 
 =head1 VERSION
 
-version v0.4.2
+version 0.004003
 
 =head1 SYNOPSIS
 
@@ -84,6 +84,12 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
+=head2 comments
+
+Reader: comments
+
+Type: Str
+
 =head2 state
 
 Reader: state
